/****************************************************************************
** Meta object code from reading C++ file 'hourlyweatherforecast.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kweathercore-26.07.80/src/hourlyweatherforecast.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'hourlyweatherforecast.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KWeatherCore21HourlyWeatherForecastE_t {};
} // unnamed namespace

template <> constexpr inline auto KWeatherCore::HourlyWeatherForecast::qt_create_metaobjectdata<qt_meta_tag_ZN12KWeatherCore21HourlyWeatherForecastE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWeatherCore::HourlyWeatherForecast",
        "date",
        "weatherDescription",
        "weatherIcon",
        "neutralWeatherIcon",
        "windDirectionDegree",
        "windDirectionCardinal",
        "KWeatherCore::WindDirection",
        "temperature",
        "pressure",
        "windSpeed",
        "humidity",
        "fog",
        "uvIndex",
        "precipitationAmount",
        "dewPointTemperature"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'date'
        QtMocHelpers::PropertyData<QDateTime>(1, QMetaType::QDateTime, QMC::DefaultPropertyFlags),
        // property 'weatherDescription'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'weatherIcon'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'neutralWeatherIcon'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'windDirectionDegree'
        QtMocHelpers::PropertyData<double>(5, QMetaType::Double, QMC::DefaultPropertyFlags),
        // property 'windDirectionCardinal'
        QtMocHelpers::PropertyData<KWeatherCore::WindDirection>(6, 0x80000000 | 7, QMC::Readable | QMC::Designable | QMC::Scriptable | QMC::EnumOrFlag),
        // property 'temperature'
        QtMocHelpers::PropertyData<qreal>(8, QMetaType::QReal, QMC::DefaultPropertyFlags),
        // property 'pressure'
        QtMocHelpers::PropertyData<qreal>(9, QMetaType::QReal, QMC::DefaultPropertyFlags),
        // property 'windSpeed'
        QtMocHelpers::PropertyData<qreal>(10, QMetaType::QReal, QMC::DefaultPropertyFlags),
        // property 'humidity'
        QtMocHelpers::PropertyData<qreal>(11, QMetaType::QReal, QMC::DefaultPropertyFlags),
        // property 'fog'
        QtMocHelpers::PropertyData<qreal>(12, QMetaType::QReal, QMC::DefaultPropertyFlags),
        // property 'uvIndex'
        QtMocHelpers::PropertyData<qreal>(13, QMetaType::QReal, QMC::DefaultPropertyFlags),
        // property 'precipitationAmount'
        QtMocHelpers::PropertyData<qreal>(14, QMetaType::QReal, QMC::DefaultPropertyFlags),
        // property 'dewPointTemperature'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HourlyWeatherForecast, qt_meta_tag_ZN12KWeatherCore21HourlyWeatherForecastE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN12KWeatherCore21HourlyWeatherForecastE[] = {
    QMetaObject::SuperData::link<KWeatherCore::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KWeatherCore::HourlyWeatherForecast::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWeatherCore21HourlyWeatherForecastE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWeatherCore21HourlyWeatherForecastE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN12KWeatherCore21HourlyWeatherForecastE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KWeatherCore21HourlyWeatherForecastE_t>.metaTypes,
    nullptr
} };

void KWeatherCore::HourlyWeatherForecast::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<HourlyWeatherForecast *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QDateTime*>(_v) = _t->date(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->weatherDescription(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->weatherIcon(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->neutralWeatherIcon(); break;
        case 4: *reinterpret_cast<double*>(_v) = _t->windDirectionDegree(); break;
        case 5: *reinterpret_cast<KWeatherCore::WindDirection*>(_v) = _t->windDirectionCardinal(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->temperature(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->pressure(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->windSpeed(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->humidity(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->fog(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->uvIndex(); break;
        case 12: *reinterpret_cast<qreal*>(_v) = _t->precipitationAmount(); break;
        case 13: *reinterpret_cast<qreal*>(_v) = _t->dewPointTemperature(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN12KWeatherCoreE_t {};
} // unnamed namespace

template <> constexpr inline auto KWeatherCore::qt_create_metaobjectdata<qt_meta_tag_ZN12KWeatherCoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWeatherCore",
        "WindDirection",
        "N",
        "NW",
        "W",
        "SW",
        "S",
        "SE",
        "E",
        "NE"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'WindDirection'
        QtMocHelpers::EnumData<WindDirection>(1, 1, QMC::EnumIsScoped).add({
            {    2, WindDirection::N },
            {    3, WindDirection::NW },
            {    4, WindDirection::W },
            {    5, WindDirection::SW },
            {    6, WindDirection::S },
            {    7, WindDirection::SE },
            {    8, WindDirection::E },
            {    9, WindDirection::NE },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN12KWeatherCoreE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN12KWeatherCoreE =
    KWeatherCore::qt_create_metaobjectdata<qt_meta_tag_ZN12KWeatherCoreE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN12KWeatherCoreE =
    qt_staticMetaObjectContent_ZN12KWeatherCoreE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN12KWeatherCoreE =
    qt_staticMetaObjectContent_ZN12KWeatherCoreE.relocatingData;

Q_CONSTINIT const QMetaObject KWeatherCore::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN12KWeatherCoreE.stringdata,
    qt_staticMetaObjectStaticContent_ZN12KWeatherCoreE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN12KWeatherCoreE.metaTypes,
    nullptr
} };

QT_WARNING_POP
