/****************************************************************************
** Meta object code from reading C++ file 'capalertinfo.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kweathercore-26.07.80/src/capalertinfo.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'capalertinfo.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KWeatherCore12CAPAlertInfoE_t {};
} // unnamed namespace

template <> constexpr inline auto KWeatherCore::CAPAlertInfo::qt_create_metaobjectdata<qt_meta_tag_ZN12KWeatherCore12CAPAlertInfoE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWeatherCore::CAPAlertInfo",
        "headline",
        "description",
        "event",
        "effectiveTime",
        "onsetTime",
        "expireTime",
        "categories",
        "Categories",
        "urgency",
        "Urgency",
        "severity",
        "Severity",
        "certainty",
        "Certainty",
        "sender",
        "instruction",
        "language",
        "languageDisplayName",
        "responseTypes",
        "ResponseTypes",
        "contact",
        "web",
        "audience",
        "resources",
        "std::vector<CAPResource>",
        "hasGeometry",
        "Category",
        "Unknown",
        "Geophysical",
        "Meteorological",
        "Safety",
        "Security",
        "Rescue",
        "Fire",
        "Health",
        "Environmental",
        "Transport",
        "Infrastructure",
        "CBRNE",
        "Other",
        "Immediate",
        "Expected",
        "Future",
        "Past",
        "UnknownUrgency",
        "Extreme",
        "Severe",
        "Moderate",
        "Minor",
        "UnknownSeverity",
        "Observed",
        "Likely",
        "Possible",
        "Unlikely",
        "UnknownCertainty",
        "ResponseType",
        "UnknownResponseType",
        "Shelter",
        "Evacuate",
        "Prepare",
        "Execute",
        "Avoid",
        "Monitor",
        "Assess",
        "AllClear",
        "None"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'headline'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'event'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'effectiveTime'
        QtMocHelpers::PropertyData<QDateTime>(4, QMetaType::QDateTime, QMC::DefaultPropertyFlags),
        // property 'onsetTime'
        QtMocHelpers::PropertyData<QDateTime>(5, QMetaType::QDateTime, QMC::DefaultPropertyFlags),
        // property 'expireTime'
        QtMocHelpers::PropertyData<QDateTime>(6, QMetaType::QDateTime, QMC::DefaultPropertyFlags),
        // property 'categories'
        QtMocHelpers::PropertyData<Categories>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'urgency'
        QtMocHelpers::PropertyData<enum Urgency>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'severity'
        QtMocHelpers::PropertyData<enum Severity>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'certainty'
        QtMocHelpers::PropertyData<enum Certainty>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'sender'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'instruction'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'language'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'languageDisplayName'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'responseTypes'
        QtMocHelpers::PropertyData<ResponseTypes>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'contact'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'web'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'audience'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'resources'
        QtMocHelpers::PropertyData<std::vector<CAPResource>>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'hasGeometry'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::Readable | QMC::Designable | QMC::Scriptable),
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'Categories'
        QtMocHelpers::EnumData<Categories>(8, 27, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {   28, Category::Unknown },
            {   29, Category::Geophysical },
            {   30, Category::Meteorological },
            {   31, Category::Safety },
            {   32, Category::Security },
            {   33, Category::Rescue },
            {   34, Category::Fire },
            {   35, Category::Health },
            {   36, Category::Environmental },
            {   37, Category::Transport },
            {   38, Category::Infrastructure },
            {   39, Category::CBRNE },
            {   40, Category::Other },
        }),
        // enum 'Urgency'
        QtMocHelpers::EnumData<enum Urgency>(10, 10, QMC::EnumIsScoped).add({
            {   41, Urgency::Immediate },
            {   42, Urgency::Expected },
            {   43, Urgency::Future },
            {   44, Urgency::Past },
            {   45, Urgency::UnknownUrgency },
        }),
        // enum 'Severity'
        QtMocHelpers::EnumData<enum Severity>(12, 12, QMC::EnumIsScoped).add({
            {   46, Severity::Extreme },
            {   47, Severity::Severe },
            {   48, Severity::Moderate },
            {   49, Severity::Minor },
            {   50, Severity::UnknownSeverity },
        }),
        // enum 'Certainty'
        QtMocHelpers::EnumData<enum Certainty>(14, 14, QMC::EnumIsScoped).add({
            {   51, Certainty::Observed },
            {   52, Certainty::Likely },
            {   53, Certainty::Possible },
            {   54, Certainty::Unlikely },
            {   55, Certainty::UnknownCertainty },
        }),
        // flag 'ResponseTypes'
        QtMocHelpers::EnumData<ResponseTypes>(20, 56, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {   57, ResponseType::UnknownResponseType },
            {   58, ResponseType::Shelter },
            {   59, ResponseType::Evacuate },
            {   60, ResponseType::Prepare },
            {   61, ResponseType::Execute },
            {   62, ResponseType::Avoid },
            {   63, ResponseType::Monitor },
            {   64, ResponseType::Assess },
            {   65, ResponseType::AllClear },
            {   66, ResponseType::None },
        }),
    };
    return QtMocHelpers::metaObjectData<CAPAlertInfo, qt_meta_tag_ZN12KWeatherCore12CAPAlertInfoE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWeatherCore::CAPAlertInfo::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWeatherCore12CAPAlertInfoE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWeatherCore12CAPAlertInfoE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KWeatherCore12CAPAlertInfoE_t>.metaTypes,
    nullptr
} };

void KWeatherCore::CAPAlertInfo::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<CAPAlertInfo *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->headline(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->event(); break;
        case 3: *reinterpret_cast<QDateTime*>(_v) = _t->effectiveTime(); break;
        case 4: *reinterpret_cast<QDateTime*>(_v) = _t->onsetTime(); break;
        case 5: *reinterpret_cast<QDateTime*>(_v) = _t->expireTime(); break;
        case 6: QtMocHelpers::assignFlags<Categories>(_v, _t->categories()); break;
        case 7: *reinterpret_cast<enum Urgency*>(_v) = _t->urgency(); break;
        case 8: *reinterpret_cast<enum Severity*>(_v) = _t->severity(); break;
        case 9: *reinterpret_cast<enum Certainty*>(_v) = _t->certainty(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->sender(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->instruction(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->language(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->languageDisplayName(); break;
        case 14: QtMocHelpers::assignFlags<ResponseTypes>(_v, _t->responseTypes()); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->contact(); break;
        case 16: *reinterpret_cast<QString*>(_v) = _t->web(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->audience(); break;
        case 18: *reinterpret_cast<std::vector<CAPResource>*>(_v) = _t->resources(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->hasGeometry(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
