/****************************************************************************
** Meta object code from reading C++ file 'capalertmessage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kweathercore-26.07.80/src/capalertmessage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'capalertmessage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KWeatherCore15CAPAlertMessageE_t {};
} // unnamed namespace

template <> constexpr inline auto KWeatherCore::CAPAlertMessage::qt_create_metaobjectdata<qt_meta_tag_ZN12KWeatherCore15CAPAlertMessageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWeatherCore::CAPAlertMessage",
        "identifier",
        "sender",
        "sentTime",
        "note",
        "status",
        "Status",
        "messageType",
        "MessageType",
        "scope",
        "Scope",
        "addresses",
        "codes",
        "alertInfos",
        "std::vector<CAPAlertInfo>",
        "preferredInfoIndexForLocale",
        "UnknownStatus",
        "Actual",
        "Exercise",
        "System",
        "Test",
        "Draft",
        "UnknownMessageType",
        "Alert",
        "Update",
        "Cancel",
        "Acknowledge",
        "Error",
        "UnknownScope",
        "Public",
        "Restricted",
        "Private"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'identifier'
        QtMocHelpers::PropertyData<QString>(1, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'sender'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'sentTime'
        QtMocHelpers::PropertyData<QDateTime>(3, QMetaType::QDateTime, QMC::DefaultPropertyFlags),
        // property 'note'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(5, 0x80000000 | 6, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'messageType'
        QtMocHelpers::PropertyData<enum MessageType>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'scope'
        QtMocHelpers::PropertyData<enum Scope>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'addresses'
        QtMocHelpers::PropertyData<QStringList>(11, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'codes'
        QtMocHelpers::PropertyData<QStringList>(12, QMetaType::QStringList, QMC::DefaultPropertyFlags),
        // property 'alertInfos'
        QtMocHelpers::PropertyData<std::vector<CAPAlertInfo>>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'preferredInfoIndexForLocale'
        QtMocHelpers::PropertyData<quint64>(15, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(6, 6, QMC::EnumIsScoped).add({
            {   16, Status::UnknownStatus },
            {   17, Status::Actual },
            {   18, Status::Exercise },
            {   19, Status::System },
            {   20, Status::Test },
            {   21, Status::Draft },
        }),
        // enum 'MessageType'
        QtMocHelpers::EnumData<enum MessageType>(8, 8, QMC::EnumIsScoped).add({
            {   22, MessageType::UnknownMessageType },
            {   23, MessageType::Alert },
            {   24, MessageType::Update },
            {   25, MessageType::Cancel },
            {   26, MessageType::Acknowledge },
            {   27, MessageType::Error },
        }),
        // enum 'Scope'
        QtMocHelpers::EnumData<enum Scope>(10, 10, QMC::EnumIsScoped).add({
            {   28, Scope::UnknownScope },
            {   29, Scope::Public },
            {   30, Scope::Restricted },
            {   31, Scope::Private },
        }),
    };
    return QtMocHelpers::metaObjectData<CAPAlertMessage, qt_meta_tag_ZN12KWeatherCore15CAPAlertMessageE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWeatherCore::CAPAlertMessage::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWeatherCore15CAPAlertMessageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KWeatherCore15CAPAlertMessageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KWeatherCore15CAPAlertMessageE_t>.metaTypes,
    nullptr
} };

void KWeatherCore::CAPAlertMessage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<CAPAlertMessage *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->identifier(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->sender(); break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->sentTime(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->note(); break;
        case 4: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 5: *reinterpret_cast<enum MessageType*>(_v) = _t->messageType(); break;
        case 6: *reinterpret_cast<enum Scope*>(_v) = _t->scope(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->addresses(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->codes(); break;
        case 9: *reinterpret_cast<std::vector<CAPAlertInfo>*>(_v) = _t->alertInfos(); break;
        case 10: *reinterpret_cast<quint64*>(_v) = _t->preferredInfoIndexForLocale(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
