/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<types.h>)
#  include <types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_weathercore()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    QMetaType::fromType<CAPAlertInfoDerived>().id();
    qmlRegisterNamespaceAndRevisions(&CAPAlertInfoDerived::staticMetaObject, "org.kde.weathercore", 1, nullptr, &CAPAlertInfoDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<CAPAlertInfoForeign>("org.kde.weathercore", 1);
    QMetaType::fromType<CAPAlertInfoForeign *>().id();
    QMetaType::fromType<CAPAlertMessageDerived>().id();
    qmlRegisterNamespaceAndRevisions(&CAPAlertMessageDerived::staticMetaObject, "org.kde.weathercore", 1, nullptr, &CAPAlertMessageDerivedForeign::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<CAPAlertMessageForeign>("org.kde.weathercore", 1);
    QMetaType::fromType<CAPAlertMessageForeign *>().id();
    qmlRegisterTypesAndRevisions<CAPAreaForeign>("org.kde.weathercore", 1);
    QMetaType::fromType<CAPAreaForeign *>().id();
    qmlRegisterTypesAndRevisions<CAPCircleForeign>("org.kde.weathercore", 1);
    QMetaType::fromType<CAPCircleForeign *>().id();
    qmlRegisterTypesAndRevisions<CAPNamedValueForeign>("org.kde.weathercore", 1);
    QMetaType::fromType<CAPNamedValueForeign *>().id();
    qmlRegisterTypesAndRevisions<CAPReferenceForeign>("org.kde.weathercore", 1);
    QMetaType::fromType<CAPReferenceForeign *>().id();
    qmlRegisterTypesAndRevisions<CAPResourceForeign>("org.kde.weathercore", 1);
    QMetaType::fromType<CAPResourceForeign *>().id();
    QMetaType::fromType<KWeatherCore::CAPAlertInfo>().id();
    qmlRegisterEnum<KWeatherCore::CAPAlertInfo::Categories>("KWeatherCore::CAPAlertInfo::Categories");
    qmlRegisterEnum<KWeatherCore::CAPAlertInfo::Category>("KWeatherCore::CAPAlertInfo::Category");
    qmlRegisterEnum<KWeatherCore::CAPAlertInfo::Urgency>("KWeatherCore::CAPAlertInfo::Urgency");
    qmlRegisterEnum<KWeatherCore::CAPAlertInfo::Severity>("KWeatherCore::CAPAlertInfo::Severity");
    qmlRegisterEnum<KWeatherCore::CAPAlertInfo::Certainty>("KWeatherCore::CAPAlertInfo::Certainty");
    qmlRegisterEnum<KWeatherCore::CAPAlertInfo::ResponseTypes>("KWeatherCore::CAPAlertInfo::ResponseTypes");
    qmlRegisterEnum<KWeatherCore::CAPAlertInfo::ResponseType>("KWeatherCore::CAPAlertInfo::ResponseType");
    QMetaType::fromType<KWeatherCore::CAPAlertMessage>().id();
    qmlRegisterEnum<KWeatherCore::CAPAlertMessage::Status>("KWeatherCore::CAPAlertMessage::Status");
    qmlRegisterEnum<KWeatherCore::CAPAlertMessage::MessageType>("KWeatherCore::CAPAlertMessage::MessageType");
    qmlRegisterEnum<KWeatherCore::CAPAlertMessage::Scope>("KWeatherCore::CAPAlertMessage::Scope");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.weathercore", 1, 0);
}

static const QQmlModuleRegistration orgkdeweathercoreRegistration("org.kde.weathercore", qml_register_types_org_kde_weathercore);
