/****************************************************************************
** Meta object code from reading C++ file 'types.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kweathercore-26.07.80/src/qml/types.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'types.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19CAPAlertInfoForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPAlertInfoForeign::qt_create_metaobjectdata<qt_meta_tag_ZN19CAPAlertInfoForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPAlertInfoForeign",
        "QML.Foreign",
        "KWeatherCore:: CAPAlertInfo",
        "QML.Element",
        "capAlertInfo"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CAPAlertInfoForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CAPAlertInfoForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CAPAlertInfoForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CAPAlertInfoForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CAPAlertInfoForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19CAPAlertInfoDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPAlertInfoDerived::qt_create_metaobjectdata<qt_meta_tag_ZN19CAPAlertInfoDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPAlertInfoDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CAPAlertInfoDerived, qt_meta_tag_ZN19CAPAlertInfoDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CAPAlertInfoDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<KWeatherCore::CAPAlertInfo>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CAPAlertInfoDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CAPAlertInfoDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CAPAlertInfoDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN22CAPAlertMessageForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPAlertMessageForeign::qt_create_metaobjectdata<qt_meta_tag_ZN22CAPAlertMessageForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPAlertMessageForeign",
        "QML.Foreign",
        "KWeatherCore:: CAPAlertMessage",
        "QML.Element",
        "capAlertMessage"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CAPAlertMessageForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CAPAlertMessageForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22CAPAlertMessageForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22CAPAlertMessageForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22CAPAlertMessageForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN22CAPAlertMessageDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPAlertMessageDerived::qt_create_metaobjectdata<qt_meta_tag_ZN22CAPAlertMessageDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPAlertMessageDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CAPAlertMessageDerived, qt_meta_tag_ZN22CAPAlertMessageDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CAPAlertMessageDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<KWeatherCore::CAPAlertMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22CAPAlertMessageDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22CAPAlertMessageDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22CAPAlertMessageDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN14CAPAreaForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPAreaForeign::qt_create_metaobjectdata<qt_meta_tag_ZN14CAPAreaForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPAreaForeign",
        "QML.Foreign",
        "KWeatherCore:: CAPArea",
        "QML.Element",
        "capArea"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CAPAreaForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CAPAreaForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CAPAreaForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CAPAreaForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14CAPAreaForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN16CAPCircleForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPCircleForeign::qt_create_metaobjectdata<qt_meta_tag_ZN16CAPCircleForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPCircleForeign",
        "QML.Foreign",
        "KWeatherCore:: CAPCircle",
        "QML.Element",
        "capCircle"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CAPCircleForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CAPCircleForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16CAPCircleForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16CAPCircleForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16CAPCircleForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN20CAPNamedValueForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPNamedValueForeign::qt_create_metaobjectdata<qt_meta_tag_ZN20CAPNamedValueForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPNamedValueForeign",
        "QML.Foreign",
        "KWeatherCore:: CAPNamedValue",
        "QML.Element",
        "capNamedValue"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CAPNamedValueForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CAPNamedValueForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CAPNamedValueForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20CAPNamedValueForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20CAPNamedValueForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19CAPReferenceForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPReferenceForeign::qt_create_metaobjectdata<qt_meta_tag_ZN19CAPReferenceForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPReferenceForeign",
        "QML.Foreign",
        "KWeatherCore:: CAPReference",
        "QML.Element",
        "capReference"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CAPReferenceForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CAPReferenceForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CAPReferenceForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CAPReferenceForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CAPReferenceForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN18CAPResourceForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPResourceForeign::qt_create_metaobjectdata<qt_meta_tag_ZN18CAPResourceForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPResourceForeign",
        "QML.Foreign",
        "KWeatherCore:: CAPResource",
        "QML.Element",
        "capResource"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<CAPResourceForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject CAPResourceForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CAPResourceForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CAPResourceForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18CAPResourceForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN26CAPAlertInfoDerivedForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPAlertInfoDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN26CAPAlertInfoDerivedForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPAlertInfoDerivedForeign",
        "QML.Element",
        "CAPAlertInfo",
        "QML.Foreign",
        "CAPAlertInfoDerived",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN26CAPAlertInfoDerivedForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN26CAPAlertInfoDerivedForeignE =
    CAPAlertInfoDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN26CAPAlertInfoDerivedForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN26CAPAlertInfoDerivedForeignE =
    qt_staticMetaObjectContent_ZN26CAPAlertInfoDerivedForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN26CAPAlertInfoDerivedForeignE =
    qt_staticMetaObjectContent_ZN26CAPAlertInfoDerivedForeignE.relocatingData;

Q_CONSTINIT const QMetaObject CAPAlertInfoDerivedForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN26CAPAlertInfoDerivedForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN26CAPAlertInfoDerivedForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN26CAPAlertInfoDerivedForeignE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN29CAPAlertMessageDerivedForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto CAPAlertMessageDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN29CAPAlertMessageDerivedForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CAPAlertMessageDerivedForeign",
        "QML.Element",
        "CAPAlertMessage",
        "QML.Foreign",
        "CAPAlertMessageDerived",
        "QML.ForeignIsNamespace",
        "true"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN29CAPAlertMessageDerivedForeignE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN29CAPAlertMessageDerivedForeignE =
    CAPAlertMessageDerivedForeign::qt_create_metaobjectdata<qt_meta_tag_ZN29CAPAlertMessageDerivedForeignE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN29CAPAlertMessageDerivedForeignE =
    qt_staticMetaObjectContent_ZN29CAPAlertMessageDerivedForeignE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN29CAPAlertMessageDerivedForeignE =
    qt_staticMetaObjectContent_ZN29CAPAlertMessageDerivedForeignE.relocatingData;

Q_CONSTINIT const QMetaObject CAPAlertMessageDerivedForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN29CAPAlertMessageDerivedForeignE.stringdata,
    qt_staticMetaObjectStaticContent_ZN29CAPAlertMessageDerivedForeignE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN29CAPAlertMessageDerivedForeignE.metaTypes,
    nullptr
} };

QT_WARNING_POP
